@@ -33,15 +33,18 @@ class RequestLoggingMiddleware:
             if hasattr(response, "data") and isinstance(response.data, (list, dict, ReturnDict)):
                 log_entry_dict["error.stack"] = response.data
             logger.warning(
-                f"HTTP {response.status_code} {response.reason_phrase}", extra=log_entry_dict,
+                f"HTTP {response.status_code} {response.reason_phrase}",
+                extra=log_entry_dict,
             )
         elif response.status_code in range(500, 600):
             log_entry_dict["error.kind"] = response.status_code
             log_entry_dict["error.message"] = response.reason_phrase
             logger.error(
-                f"HTTP {response.status_code} {response.reason_phrase}", extra=log_entry_dict,
+                f"HTTP {response.status_code} {response.reason_phrase}",
+                extra=log_entry_dict,
             )
         else:
             logger.info(
-                f"HTTP {response.status_code} {response.reason_phrase}", extra=log_entry_dict,
+                f"HTTP {response.status_code} {response.reason_phrase}",
+                extra=log_entry_dict,
             )
